@@ -87,8 +87,13 @@ class Connection():
 
 
     def __format_join_query__(self, joined, type):
-        _selects_stetaments = []
+        if self._select:
+            _selects_stetaments = ', '.join([f"{c} AS '{c}'" for c in self._select if self.__is__join_select__(c)])
+        else:
+            _selects_stetaments = ''
+
         _joins_stetaments = []
+
         if joined:
             count = 0
             for join in joined:
@@ -96,20 +101,19 @@ class Connection():
                 join_class = self._klass[join]()
                 join_key = self._klass[join]
 
-                _select_join = [f"{c} AS '{c}'" for c in self._select if self.__is_clause_join__(join, c)] if self._select else []
-                if len(_select_join) == 0:
-                    _select_join = [f"{join}.{field} AS '{join}.{field}'" for field in join_class.__dict__ if not field.startswith("_") and not join_class[field].__class__.__name__.startswith("Obj")]
+                if self._select:
+                    if not all([f'{join}.{pk}' in _selects_stetaments for pk in join_class.__metadata__['pk']]):
+                        _select_join_pks = ", ".join([f"{join}.{pk} AS '{join}.{pk}'" for pk in join_class.__metadata__['pk']])
+                        _selects_stetaments = f"{_selects_stetaments}, {_select_join_pks}"
+                else:
+                    _select_join = ", ".join([f"{join}.{field} AS '{join}.{field}'" for field in join_class.__dict__ if not field.startswith("_") and not join_class[field].__class__.__name__.startswith("Obj")])
+                    _selects_stetaments = f"{_selects_stetaments}, {_select_join}" if _selects_stetaments != '' else _select_join
 
-                _select_join = ", ".join(_select_join)
-                if not all([f'{join}.{pk}' in _select_join for pk in join_class.__metadata__['pk']]):
-                    _select_join = _select_join + ", " + ", ".join([f"{join}.{field} AS '{join}.{field}'" for field in join_class.__dict__ if not field.startswith("_") and field in join_class.__metadata__['pk']])
-
-                _selects_stetaments.append(_select_join)
 
                 # CODITIONS OF JOIN
                 _coditions = []
 
-                __conditions_join = [w for w in self._where if self.__is_clause_join__(join, w)] if self._where else []
+                __conditions_join = [w for w in self._where if self.__is__join_or_include_codition__(join, w)] if self._where else []
 
 
                 if self._klass[join].__class__.__name__ != "ObjListOfMany":
@@ -121,7 +125,7 @@ class Connection():
                         _coditions.append(f"{_base_join.replace('()','').replace(')','')} AND {' AND '.join(__conditions_join)})")
 
                         # ORWHERE
-                        _coditions.extend([c for c in [f" OR ( {_base_join.replace('(','').replace(')','')} AND {' AND '.join([w for w in conditions if self.__is_clause_join__(join, w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()'] if self._orwhere else [])
+                        _coditions.extend([c for c in [f" OR ( {_base_join.replace('(','').replace(')','')} AND {' AND '.join([w for w in conditions if self.__is__join_or_include_codition__(join, w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()'] if self._orwhere else [])
 
                     else:
                         _coditions.append(_base_join)
@@ -138,7 +142,7 @@ class Connection():
                         _coditions.append(f"{_base_join} AND {' AND '.join(__conditions_join)}")
 
                         # ORWHERE
-                        _coditions.extend([c for c in [f" OR {_base_join} AND {' AND '.join([w for w in conditions if self.__is_clause_join__(join, w)])}" for block, conditions in self._orwhere.items()] if c.strip() != 'OR'] if self._orwhere else [])
+                        _coditions.extend([c for c in [f" OR {_base_join} AND {' AND '.join([w for w in conditions if self.__is__join_or_include_codition__(join, w)])}" for block, conditions in self._orwhere.items()] if c.strip() != 'OR'] if self._orwhere else [])
 
                     else:
 
@@ -148,31 +152,30 @@ class Connection():
                     _joins_stetaments.append(f"{type} JOIN {join_key.intermediate} AS inter_{count}_{join_key.intermediate} ON  inter_{count}_{join_key.intermediate}.{join_key.ref_key} = {self._table}.{join_key.reference} {type} JOIN {join_key.table} AS {join_key.keyname} ON {' '.join(_coditions)}")
 
 
-        return ", ".join(_selects_stetaments), " ".join(_joins_stetaments)
+        return _selects_stetaments, " ".join(_joins_stetaments)
 
     def __format_include_query__(self, obj, include):
 
         _include_key = self._klass[include]
         _include_class = self._klass[include]()
 
-        _select_join = [f"{c.replace(f'{include}.', '')} AS '{c.replace(f'{include}.', '')}'" for c in self._select if self.__is_clause_join__(include, c)] if self._select else []
+        if self._select:
+            _include_select = ", ".join([f"{c.replace(f'{include}.', '')} AS '{c.replace(f'{include}.', '')}'" for c in self._select if self.__is__include_select__(include, c)])
+            if not all([f"'{pk}'" in _include_select for pk in _include_class.__metadata__['pk']]):
+                _pk_select = ", ".join([f"{pk} AS '{pk}'" for pk in _include_class.__metadata__['pk']])
+                _include_select = f"{_include_select}, {_pk_select}"
+        else:
+            _include_select = ", ".join([f"{field} AS '{field}'" for field in _include_class.__dict__ if not field.startswith("_") and not _include_class[field].__class__.__name__.startswith("Obj")])
 
-        if len(_select_join) == 0:
-            _select_join = [f"{field} AS '{field}'" for field in _include_class.__dict__ if not field.startswith("_") and not _include_class[field].__class__.__name__.startswith("Obj")]
-
-        _include_select = ", ".join(_select_join)
-
-        if not all([f"'{pk}'" in _include_select for pk in _include_class.__metadata__['pk']]):
-            _include_select = _include_select + ", " + ", ".join([f"{field} AS '{field}'" for field in _include_class.__dict__ if not field.startswith("_") and field in _include_class.__metadata__['pk']])
 
         _default_condition = f'{include}.{_include_key.key} = {obj[_include_key.reference].value}'
 
-        __conditions_include = " AND ".join([w for w in self._where if self.__is_clause_join__(include, w)]) if self._where else ""
+        __conditions_include = " AND ".join([w for w in self._where if self.__is__join_or_include_codition__(include, w)]) if self._where else ""
 
         _where = []
         if len(__conditions_include)>0:
             _where.append(f"( {_default_condition} AND {__conditions_include} )")
-            _orwhere = '' if len(self._orwhere) == 0 else ' OR '.join([f"( {_default_condition} AND {' AND '.join([w for w in conditions if self.__is_clause_join__(include, w)])} )" for block, conditions in self._orwhere.items()])
+            _orwhere = '' if len(self._orwhere) == 0 else ' OR '.join([f"( {_default_condition} AND {' AND '.join([w for w in conditions if self.__is__join_or_include_codition__(include, w)])} )" for block, conditions in self._orwhere.items()])
             if _orwhere != '':
                 _where.append(_orwhere)
         else:
@@ -191,42 +194,81 @@ class Connection():
             stetament = ReplaceData(f"SELECT {_include_select} FROM {include} WHERE {' OR '.join(_where)}")
         else:
             _where = ""
-            __conditions_include = " AND ".join([w for w in self._where if self.__is_clause_join__(include, w)]) if self._where else ""
+            __conditions_include = " AND ".join([w for w in self._where if self.__is__join_or_include_codition__(include, w)]) if self._where else ""
             if len(__conditions_include)>0:
                 _where = f"WHERE ({__conditions_include})"
-                _orwhere = '' if len(self._orwhere) == 0 else ' OR '.join([f"({' AND '.join([w for w in conditions if self.__is_clause_join__(include, w)])} )" for block, conditions in self._orwhere.items()])
+                _orwhere = '' if len(self._orwhere) == 0 else ' OR '.join([f"({' AND '.join([w for w in conditions if self.__is__join_or_include_codition__(include, w)])} )" for block, conditions in self._orwhere.items()])
                 if len(_orwhere)>0:
-                    _where = f"{_where} OR {_orwhere}"
+                    _where = f"t{_where} OR {_orwhere}"
             stetament = f"SELECT {_include_select} FROM {_include_key.table} {include} INNER JOIN {_include_key.intermediate} inter_{_include_key.intermediate} ON (inter_{_include_key.intermediate}.{_include_key.rel_key} = {include}.{_include_key.key} AND inter_{_include_key.intermediate}.{_include_key.ref_key} = {obj[ _include_key.reference].value}) {_where}"
         return stetament
 
-    def __is_clause_table__(self, condition):
-        if not '.' in condition or len(re.findall(r"\"\S+\.\S+\"|\'\S+\.\S+\'|\d+\.\d+?", condition)) > 0:
+
+    def __is_join__(self, table_name):
+        return tb_name in self._join or tb_name in self._inner
+
+    def __is_include__(self, table_name):
+        return tb_name in self._include
+
+    def __is__main_select__(self, field):
+        if not '.' in field:
             return True
         else:
-            if not f"{self._table}." in condition:
-                return False
-            else:
-                return not any(([f"{j}." in condition for j in self._join] if self._join else []) + ([f"{i}." in condition for i in self._inner] if self._inner else []) + ([f"{i}." in condition for i in self._include] if self._include else []))
+            table_name = field.split('.')[0].strip()
+            return not self.__is_join__(table_name) and not self.__is_include__(table_name)
 
-    def __is_clause_join__(self, join, condition):
+    def __is__join_select__(self, field):
+        if '.' in field:
+            table_name = field.split('.')[0].strip()
+            return not self.__is_join__(table_name)
+        else:
+            return False
+
+    def __is__include_select__(self, include, field):
+        if '.' in field:
+            table_name = field.split('.')[0].strip()
+            return table_name == include
+        else:
+            return False
+
+
+    def __is__main_codition__(self, condition):
+        if not self._join and not self._inner and not self._include:
+            return True
+        else:
+            if not '.' in condition:
+                return True
+            else:
+                is_join = any([self.__is__join_or_include_codition__(join, condition) for join in self._join]) if self._join else False
+                is_inner = any([self.__is__join_or_include_codition__(inner, condition) for inner in self._inner]) if self._inner else False
+                is_include = any([self.__is__join_or_include_codition__(include, condition) for include in self._include]) if self._include else False
+                return not is_join and not is_inner and not is_include
+
+    def __is__join_or_include_codition__(self, table, condition):
         if not '.' in condition:
             return False
         else:
-            return f"{join}." in condition
+            return f'{table}.' in condition and not re.match("\w+"+ table + "\.", condition)
 
     def __format_select_query__(self):
-        # SELECT BLOCK
-        _select = '*' if not self._select else ', '.join([f"{self._table}.{c} AS '{c}'" for c in self._select if self.__is_clause_table__(c)])
 
-        if _select == '*':
+        # SELECT BLOCK
+        if self._select:
+            _select = ', '.join([f"{self._table}.{c} AS '{c}'" for c in self._select if self.__is__main_select__(c)])
+            # IF NOT PRIMARY KEY ON SELECT, APPEND IT
+            if not all([f'{self._table}.{pk}' in _select for pk in self._klass.__metadata__['pk']]):
+                _select_pk = ', '.join([f"{self._table}.{pk} AS '{pk}'" for pk in self._klass.__metadata__['pk']])
+                _select = f"{_select}, {_select_pk}"
+        else:
             _select = ", ".join([f"{self._table}.{field} AS '{field}'" for field in self._klass.__dict__ if not field.startswith("_") and not self._klass[field].__class__.__name__.startswith("Obj")])
-        if not all([f'{self._table}.{pk}' in _select for pk in self._klass.__metadata__['pk']]):
-            _select = _select + ", " + ", ".join([f"{self._table}.{field} AS '{field}'" for field in self._klass.__dict__ if not field.startswith("_") and field in self._klass.__metadata__['pk']])
+
 
         _distinct = f'DISTINCT({",".join(self._distinct)})' if self._distinct else None
+
         _select = f"{_select}, {_distinct}" if _distinct else f"{_select}"
+
         _alias = ",".join([f'{alias[0]} AS {alias[1]}' for alias in self._alias]) if self._alias else None
+
         _select = f"{_select}, {_alias}" if _alias else f"{_select}"
 
         _select_join, _join = self.__format_join_query__(self._join, 'LEFT')
@@ -236,9 +278,9 @@ class Connection():
         _select_inner = f', {_select_inner}' if _select_inner != '' else ''
 
         # CONDITION BLOCK
-        _where = [w for w in self._where if self.__is_clause_table__(w)] if self._where else []
+        _where = [w for w in self._where if self.__is__main_codition__(w)] if self._where else []
         _where = f" WHERE ({' AND '.join(_where)})" if len(_where) > 0 else ''
-        _orwhere = ''.join([c for c in [f" OR ({' AND '.join([w for w in conditions if self.__is_clause_table__(w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()']) if self._orwhere else ''
+        _orwhere = ''.join([c for c in [f" OR ({' AND '.join([w for w in conditions if self.__is__main_codition__(w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()']) if self._orwhere else ''
 
         # GROUP BLOCK
         _groupby =  '' if not self._groupby else f" GROUP BY ({self._groupby})"
@@ -279,9 +321,9 @@ class Connection():
         _select_inner = f', {_select_inner}' if _select_inner != '' else ''
 
         # CONDITION BLOCK
-        _where = [w for w in self._where if self.__is_clause_table__(w)] if self._where else []
+        _where = [w for w in self._where if self.__is__main_codition__(w)] if self._where else []
         _where = f" WHERE ({' AND '.join(_where)})" if len(_where) > 0 else ''
-        _orwhere = ''.join([c for c in [f" OR ({' AND '.join([w for w in conditions if self.__is_clause_table__(w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()']) if self._orwhere else ''
+        _orwhere = ''.join([c for c in [f" OR ({' AND '.join([w for w in conditions if self.__is__main_codition__(w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()']) if self._orwhere else ''
 
         # GROUP BLOCK
         _groupby =  '' if not self._groupby else f" GROUP BY ({self._groupby})"
@@ -309,7 +351,7 @@ class Connection():
             raise Exception(f"Can't delete object {obj.__class__.__name__} whitout primary key defined")
 
     def __format_delete_query__(self):
-        _where = [w for w in self._where if self.__is_clause_table__(w)]
+        _where = [w for w in self._where if self.__is__main_codition__(w)]
         return f"DELETE FROM {self._table} WHERE ({' AND '.join(_where)})"
 
     def __format_object_insert_query__(self, obj):
@@ -407,16 +449,16 @@ class Connection():
         query = self.__format_select_query__()
         result = self._conn.fetchall(query)
 
-        result = self._class(aliases=self._alias, **result[0]) if result else None
-        if self._include:
+        item = self._class(aliases=self._alias, **result[0]) if result else None
+        if item and self._include:
             for _include in self._include:
                 item[_include].__reset__()
                 item.__metadata__['relasionships'][_include] = None if not 'List' in item[_include].__class__.__name__ else []
-                _stetament_include = self.__format_include_query__(result, _include)
+                _stetament_include = self.__format_include_query__(item, _include)
                 _include_result = self._conn.fetchall(_stetament_include)
-                result.add(_include, _include_result)
+                item.add(_include, _include_result)
 
-        return result
+        return item
 
     @property
     def count(self):
@@ -483,9 +525,9 @@ class Connection():
 
 
     def set(self, field, value):
-        _where = [w for w in self._where if self.__is_clause_table__(w)] if self._where else []
+        _where = [w for w in self._where if self.__is__main_codition__(w)] if self._where else []
         _where = f" WHERE ({' AND '.join(_where)})" if len(_where) > 0 else ''
-        _orwhere = ''.join([c for c in [f" OR ({' AND '.join([w for w in conditions if self.__is_clause_table__(w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()']) if self._orwhere else ''
+        _orwhere = ''.join([c for c in [f" OR ({' AND '.join([w for w in conditions if self.__is__main_codition__(w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()']) if self._orwhere else ''
         query = f"UPDATE {self._table} SET {field}='{value}' {_where}{_orwhere}"
         self._conn.save(query, {})
         self._conn.commit()
