@@ -60,6 +60,8 @@ class Portugues():
         ]
 
         irregular_words = {
+            'direct': 'directs',
+            'inbox': 'inboxes',
             'session': 'sessions',
             'fan': 'fans',
             'feed': 'feeds',
@@ -153,6 +155,8 @@ class Portugues():
             ]
 
             irregular_words = {
+                'directs': 'direct',
+                'inboxes': 'inbox',
                 'sessions': 'session',
                 'fans': 'fan',
                 'feeds': 'feed',
