@@ -6,7 +6,6 @@ import os
 import re
 
 sys.path.append('/Users/robertoneves/Projetos/bravaorm/')
-sys.path.append('/Users/robertoneves/Projetos/dbmodel/')
 
 import bravaorm
 from model import *
@@ -19,9 +18,9 @@ def main(arg):
 
     conn = bravaorm.Connection(db_user="root", db_password="1234", db_host="127.0.0.1", db_port=3306, db_database="gofans", db_charset="utf8mb4", log_level='debug')
 
-    usuarios = conn.usuarios.include("idolos, fans").inner("idolos", "fans").groupby("usuarios.id").all
+    usuario = conn.usuarios.join("postagens").where("id = 46, postagens.id>0").first
 
-    print(json.dumps(usuarios.toJSON(), indent=14))
+    print(usuario.fans)
 
     conn.close()
 
